#ifndef CONJ_EST_HPP
#define CONJ_EST_HPP

#include "Estudiant.hpp"
#include <vector>

class Cjt_estudiants {

private:

  // Representa un conjunt ordenat per DNI d'estudiants.  
  // Es poden consultar i modificar els seus elements  
  // (de tipus Estudiant) donat un DNI o per posici en l'ordre.
  vector<Estudiant> vest;
  int nest;
  static const int MAX_NEST = 60;

public:

  //Constructores

  Cjt_estudiants();
  /* Pre: cert */
  /* Post: el resultat s un conjunt d'estudiants buit */

  //Destructora

  ~Cjt_estudiants();
   
  //Modificadores

  void afegir_estudiant(const Estudiant &est);
  /* Pre: el parmetre implcit no cont cap estudiant amb el dni d'est */
  /* Post: s'ha afegit l'estudiant est al parmetre implcit */

  void modificar_estudiant(const Estudiant &est);
  /* Pre: existeix un estudiant al parmetre implcit amb el DNI d'est  */
  /* Post: l'estudiant del parmetre implcit original amb el dni
     d'est, ha quedat substitut per est */
		
  void modificar_iessim(int i, const Estudiant &est);
  /* Pre: 1 <= i <= nombre d'estudiants del parmetre implcit,
     l'element i-ssim del conjunt en ordre creixent per DNI cont 
     un estudiant amb el mateix DNI que est */
  /* Post: l'estudiant est ha substitut l'estudiant i-ssim
     del parmetre implcit */

  //Consultores
	
  int mida() const;
  /* Pre: cert */
  /* Post: el resultat s el nombre d'estudiants del parmetre implcit */

  bool existeix_estudiant(int dni) const;
  /* Pre: dni > 0 */
  /* Post: el resultat indica si existeix un estudiant al parmetre implcit
     amb DNI = dni */

  Estudiant consultar_estudiant(int dni) const;
  /* Pre: existeix un estudiant al parmetre implcit amb DNI = dni */
  /* Post: el resultat s l'estudiant amb DNI = dni que cont el 
     parmetre implcit */

  Estudiant consultar_iessim(int i) const;
  /* Pre: 1 <= i <= nombre d'estudiants que cont el parmetre implcit */
  /* Post: el resultat s l'estudiant i-ssim del parmetre implcit 
     en ordre creixent per DNI */
		
  // Lectura i escriptura
	
  void llegir_cjt_estudiants();
  /* Pre: cert */
  /* Post: el parmetre implcit cont el conjunt d'estudiants llegits
     del canal estndard d'entrada */

  void escriure_cjt_estudiants() const;
  /* Pre: cert */
  /* Post: s'han escrit pel canal estndard de sortida els estudiants del
     parmetre implcit en ordre ascendent per DNI */

private:

  void ordenar_cjt_estudiants ();

};

#endif
